==> kmix-17.12.2.tar.xz: kmix-17.12.2/core/kmixdevicemanager.h <==
/*
 * KMix -- KDE's full featured mini mixer
 *
 * Copyright 2006-2007 Christian Esken <esken@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef kmixdevicemanager_h
#define kmixdevicemanager_h

#include <QObject>

class KMixDeviceManager : public QObject
{
  Q_OBJECT

    public:
        static KMixDeviceManager* instance();
        void initHotplug();
        void setHotpluggingBackends(const QString& backendName) { _hotpluggingBackend = backendName; } ;
        QString getUDI_ALSA(int num);
        QString getUDI_OSS(const QString& devname);

    signals:
        void plugged( const char* driverName, const QString& udi, QString& dev);
        void unplugged( const QString& udi);

    private:
        KMixDeviceManager();
        ~KMixDeviceManager();
        QString _hotpluggingBackend;
        
    private slots:
        void pluggedSlot(const QString&);
        void unpluggedSlot(const QString&);

    private:
        static KMixDeviceManager* s_KMixDeviceManager;
};

#endif

==> kmix-18.12.3.tar.xz: kmix-18.12.3/core/kmixdevicemanager.h <==
/*
 * KMix -- KDE's full featured mini mixer
 *
 * Copyright 2006-2007 Christian Esken <esken@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef kmixdevicemanager_h
#define kmixdevicemanager_h

#include <QObject>

#include "kmixcore_export.h"

class KMIXCORE_EXPORT KMixDeviceManager : public QObject
{
  Q_OBJECT

    public:
        static KMixDeviceManager* instance();
        void initHotplug();
        void setHotpluggingBackends(const QString& backendName) { _hotpluggingBackend = backendName; } ;
        QString getUDI_ALSA(int num);
        QString getUDI_OSS(const QString& devname);

    signals:
        void plugged( const char* driverName, const QString& udi, QString& dev);
        void unplugged( const QString& udi);

    private:
        KMixDeviceManager();
        ~KMixDeviceManager();
        QString _hotpluggingBackend;
        
    private slots:
        void pluggedSlot(const QString&);
        void unpluggedSlot(const QString&);

    private:
        static KMixDeviceManager* s_KMixDeviceManager;
};

#endif
